@@ -16,8 +16,9 @@ def writeErrorLog(outputFilePath, errorText):
     """
 
     # エラーログの出力先がない場合、作成する
-    if os.path.exists(outputFilePath) == False:
-        os.mkdir(outputFilePath)
+    outputFolderPath = os.path.dirname(outputFilePath)
+    if os.path.exists(outputFolderPath) == False:
+        os.mkdir(outputFolderPath)
     
     # エラー出力
     with open(outputFilePath, 'a') as f:
