@@ -196,6 +196,8 @@ class recset(Generic[T]):
         # dfrowsのカレント行の行状態をmodifiedに変更
         if self.__dfrows.loc[self.__currentRowIndex, self.__ROWSTATE_COLNAME__] == self.rowState.noChanged:
             self.__dfrows.loc[self.__currentRowIndex, self.__ROWSTATE_COLNAME__] = __rowState
+        #if self.__dfrows.iloc[self.__currentRowIndex][self.__ROWSTATE_COLNAME__] == self.rowState.noChanged:
+        #    self.__dfrows.iloc[self.__currentRowIndex][self.__ROWSTATE_COLNAME__] = __rowState
 
     def fields(self, __columnName:T):
         
@@ -834,19 +836,27 @@ class recset(Generic[T]):
             self.__dfrows:pd.DataFrame = self.__dfrows[dfw]
             
             # rows初期化
-            self.__rows = []
+            rowsTemp = []
+            
+            # __rowsをフィルタする
+            for index, item in self.__dfrows.iterrows():
+                for row in self.__rows:
+                    for key in self.__getPrimaryKeys():
+                        if getattr(row, key) == item[key]:
+                            rowsTemp.append(row)
+            self.__rows = rowsTemp
 
+            # __dfrowsを再構築する
+            rowIndex = 0
+            self.__dfrows = self.__initdfrows()
+            for row in self.__rows:
+                # DataFrame - add
+                self.__addRecrowDataFrame(row, rowIndex)
+                rowIndex += 1
+            
             # フィールドクラス
             self.__fields = fields(self.__rows, self.__dfrows)
             
-            # dfrowsループ
-            for index, item in self.__dfrows.iterrows():
-                row = self.modelType()
-                row.__rowState = self.rowState.noChanged
-                for col in self.__columns:
-                    setattr(row, col[0], item[col[0]])
-                self.__rows.append(row)
-
         # カレント行インデックス初期化
         self.__currentRowIndex = -1
 
@@ -876,7 +886,18 @@ class recset(Generic[T]):
                 for expr in wx.andList:
                     andExpr:BinaryExpression = expr
                     if not type(andExpr.right.value) is list:
-                        andExprList.append(df[andExpr.left.key] == andExpr.right.value)
+                        if andExpr.operator.__name__ == "eq":
+                            andExprList.append(df[andExpr.left.key] == andExpr.right.value)
+                        elif andExpr.operator.__name__ != "ne":
+                            andExprList.append(df[andExpr.left.key] != andExpr.right.value)
+                        elif andExpr.operator.__name__ != "gt":
+                            andExprList.append(df[andExpr.left.key] > andExpr.right.value)
+                        elif andExpr.operator.__name__ != "lt":
+                            andExprList.append(df[andExpr.left.key] < andExpr.right.value)
+                        elif andExpr.operator.__name__ != "ge":
+                            andExprList.append(df[andExpr.left.key] >= andExpr.right.value)
+                        elif andExpr.operator.__name__ != "le":
+                            andExprList.append(df[andExpr.left.key] <= andExpr.right.value)
                     else:
                         dfInExpr = None
                         for rval in andExpr.right.value:
